@@ -26,7 +26,6 @@ def time_task():
         "sequenceNum": sequenceNum,
         "ip": ip,
     }
-    print(jsonData)
     is3Api = iS3PythonApi(filePath, None)
     response = is3Api.sendHeartbeat(jsonData)
     if response.get('code') == 500:
@@ -37,5 +36,4 @@ def time_task():
     revRequestId = data.get('requestId')
     # 校验requestId是否相同
     if int(requestId) == int(revRequestId):
-        print(data.get("sequenceNum"))
         sequenceNum = int(data.get("sequenceNum")) + 1
