@@ -9,11 +9,12 @@ def create_data_entity(filePath, jsonData):
     serverName = get_server_name(filePath, 'server')
     headers = get_header(filePath, 'key')
     dataDto = DataEntity(
-        preData=jsonData['data'],
-        pluginDataConfig=jsonData['pluginDataConfig'],
+        preData=jsonData.get('data', {}),
+        pluginDataConfig=jsonData.get('pluginDataConfig', {}),
         taskInstanceId=1111,
         taskId=1,
         nodeId=1,
+        customInstanceCode=1,
         logId=1,
         serverName=serverName,
         headers=headers,
